==> seedsui-react-5.8.81.tgz: package/lib/Map/utils/wgs84ToCoords/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
// 内库使用
import GeoUtil from "./../../../GeoUtil";

// 测试使用
// import { GeoUtil } from 'seedsui-react'

// 单个点转换
function getPoint(point, type) {
  if (!(point !== null && point !== void 0 && point.longitude) || !(point !== null && point !== void 0 && point.latitude)) {
    console.error('MapContainer wgs84ToCoords invalid parameter:', point);
    return null;
  }
  // 无需要转换
  if (!point.type && !type) return point;
  var newPoint = GeoUtil.coordtransform([point.longitude, point.latitude], 'wgs84', point.type || type);
  return _objectSpread(_objectSpread({}, point), {}, {
    type: point.type || type,
    longitude: newPoint[0],
    latitude: newPoint[1]
  });
}

// 转成wgs84坐标
function wgs84ToCoords(points, type) {
  if (Array.isArray(points) && points.length) {
    return points.map(function (point) {
      return getPoint(point, type);
    });
  } else if (toString.call(points) === '[object Object]') {
    return getPoint(points, type);
  }
  return null;
}
export default wgs84ToCoords;

==> seedsui-react-5.8.90.tgz: package/lib/Map/utils/wgs84ToCoords/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
// 内库使用
import GeoUtil from "./../../../GeoUtil";

// 测试使用
// import { GeoUtil } from 'seedsui-react'

// 单个点转换
function getPoint(point, type) {
  if (!(point !== null && point !== void 0 && point.longitude) || !(point !== null && point !== void 0 && point.latitude)) {
    console.error('MapContainer wgs84ToCoords invalid parameter:', point);
    return null;
  }
  // 无需要转换
  if (!type) return point;
  var newPoint = GeoUtil.coordtransform([point.longitude, point.latitude], point.type || 'wgs84', type);
  return _objectSpread(_objectSpread({}, point), {}, {
    type: type,
    longitude: newPoint[0],
    latitude: newPoint[1]
  });
}

// 转成wgs84坐标
function wgs84ToCoords(points, type) {
  if (Array.isArray(points) && points.length) {
    return points.map(function (point) {
      return getPoint(point, type);
    });
  } else if (toString.call(points) === '[object Object]') {
    return getPoint(points, type);
  }
  return null;
}
export default wgs84ToCoords;
